@@ -1,5 +1,4 @@
 import sys
-
 version = int(sys.version[0])
 is_python3 = version == 3
 
@@ -36,6 +35,8 @@ def ljust(source, size, by):
     length = (size - len(source))
     if length < 0:
         length = 0
+    if length < 0:
+        raise Exception("Can't ljust data, size: {}, just: {}".format(len(source), by))
     source += by * length
-    assert len(source) == size
+    assert len(source) == size, "Error size: {}, len(source) = {}, by = {}".format(size, len(source), by)
     return source
\ No newline at end of file
