@@ -1,3 +1,4 @@
+import binascii
 import os
 
 from elftools.elf.elffile import ELFFile
@@ -221,8 +222,10 @@ class Shellcode(object):
             relocation_entry = relocation_size + relocation_entry
             table += relocation_entry
 
-        size_encoded = self.pack_pointer(len(table))
-        return self.pack_pointer(self.shellcode_table_magic) + size_encoded + self.pre_table_header + table
+        sizes = self.pack_list_of_pointers([len(table),
+                                            len(self.get_shellcode_header())])
+
+        return self.pack_pointer(self.shellcode_table_magic) + sizes + self.pre_table_header + table
 
     @property
     def pre_table_header(self):
@@ -369,6 +372,7 @@ class Shellcode(object):
             check_x=False,
             attribute="p_vaddr"
         )
+
     @property
     def linker_base_address(self):
         return self.get_linker_base_address()
@@ -415,23 +419,31 @@ class Shellcode(object):
         shellcode_data = self.do_objdump(shellcode_data)
         # This must be here !
         relocation_table = self.relocation_table
-        if self.args.output_format == OUTPUT_FORMAT_MAP.eshelf:
-            return self.build_eshelf(
-
-                relocation_table=relocation_table,
-                shellcode_header=shellcode_header,
-                shellcode_data=shellcode_data
-            )
 
         full_header = self.loader + relocation_table + shellcode_header
         if self.args.save_without_header:
             self.logger.info("Saving without shellcode table")
-            return shellcode_data
+            formatted_shellcode = shellcode_data
         else:
-            return self.build_shellcode_from_header_and_code(full_header, shellcode_data)
+            formatted_shellcode = self.build_shellcode_from_header_and_code(full_header, shellcode_data)
 
-    def build_eshelf(self, relocation_table, shellcode_header, shellcode_data):
-        shellcode_data = relocation_table + shellcode_header + shellcode_data
+        return self.post_make_shellcode_handle_format(formatted_shellcode)
+
+    def post_make_shellcode_handle_format(self, shellcode):
+        shellcode_with_output_format = shellcode
+        if self.args.output_format == OUTPUT_FORMAT_MAP.eshelf:
+            shellcode_no_loader = self.remove_loader_from_shellcode(shellcode)
+            shellcode_with_output_format = self.build_eshelf(
+                shellcode_data=shellcode_no_loader
+            )
+        return shellcode_with_output_format
+
+    def remove_loader_from_shellcode(self, shellcode):
+        index = shellcode.find(self.loader)
+        assert index != -1
+        return shellcode[:index] + shellcode[index+len(self.loader):]
+
+    def build_eshelf(self, shellcode_data):
         loader = lief.parse(self.loader_path)
         segment = lief.ELF.Segment()
         segment.type = lief.ELF.SEGMENT_TYPES.LOAD
@@ -457,9 +469,17 @@ class Shellcode(object):
         self.logger.info("Setting shellcode base address at: {}".format(
             hex(segment.virtual_address)
         ))
+        # Offset to where the shellcode starts
         shellcode_start = self.pack_pointer(segment.virtual_address)
+
+        # Offset to the entry point of the loader
         elf_buffer_with_address = elf_buffer[:loader_symbol_address]
+
+        # Setting the eshelf entry point to shellcode_start
+        # Thats because the start of the shellcode is the relocation table
         elf_buffer_with_address += shellcode_start
+        self.logger.info("Setting relocation table address to: {}".format(hex(segment.virtual_address)))
+        # Adding the rest of the shellcode into the buffer
         elf_buffer_with_address += elf_buffer[loader_symbol_address + self.ptr_size:]
         return elf_buffer_with_address
 
@@ -504,6 +524,9 @@ class Shellcode(object):
         current_offset += self.ptr_size  # skipping magic
         table_size = self.unpack_ptr(header[current_offset:current_offset + self.ptr_size])
         current_offset += self.ptr_size  # skip ptr size
+        header_size = self.unpack_ptr(header[current_offset:current_offset + self.ptr_size])
+        current_offset += self.ptr_size  # skip ptr header size
+
         current_offset += len(self.pre_table_header)
 
         handled_size = 0
